@@ -18,7 +18,6 @@
 
 #include <QUrl>
 #include <QMap>
-#include <KDialog>
 #include <KPageDialog>
 
 class DetailedGraphicalOverview;
@@ -41,7 +40,7 @@ class DetailedInfoDlg : public KPageDialog
     Q_OBJECT
 
 public:
-    explicit DetailedInfoDlg(int el, QWidget *parent = 0);
+    explicit DetailedInfoDlg(int el, QWidget *parent = nullptr);
     ~DetailedInfoDlg();
 
     void setElement(int el);
