@@ -15,8 +15,9 @@
 
 #include <QTimer>
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <QDebug>
+#include <KLocalizedString>
+#include <QIcon>
 
 #include <element.h>
 #include <math.h>
@@ -41,7 +42,7 @@ GradientWidgetImpl::GradientWidgetImpl(QWidget *parent) : QWidget(parent), m_pla
     connect(Play, SIGNAL(clicked()), this, SLOT(play()));
     connect(m_timer, SIGNAL(timeout()), this, SLOT(tick()));
 
-    Play->setIcon(KIcon("media-playback-start"));
+    Play->setIcon(QIcon::fromTheme("media-playback-start"));
 }
 
 GradientWidgetImpl::~GradientWidgetImpl()
@@ -214,14 +215,14 @@ void GradientWidgetImpl::play(void)
     m_timer->start(200);
 
     m_play = true;          //start playing
-    Play->setIcon(KIcon("media-playback-pause"));
+    Play->setIcon(QIcon::fromTheme("media-playback-pause"));
 }
 
 void GradientWidgetImpl::stop(void)
 {
     //Currently playing, stop the timer.
     m_timer -> stop();
-    Play->setIcon(KIcon("media-playback-start"));
+    Play->setIcon(QIcon::fromTheme("media-playback-start"));
     m_play = false;         //Stop
 }
 
@@ -235,4 +236,3 @@ void GradientWidgetImpl::tick(void)
     }
     gradient_slider -> setValue (temp + increment);
 }
-// #include "gradientwidget_impl.moc"
