@@ -11,7 +11,7 @@
 #ifndef KDEEDUGLOSSARY_H
 #define KDEEDUGLOSSARY_H
 
-#include <kdialog.h>
+#include <QDialog>
 #include <QUrl>
 
 class QDomDocument;
@@ -203,7 +203,7 @@ private:
  * @author Pino Toscano
  * @author Carsten Niehaus
  */
-class GlossaryDialog : public KDialog
+class GlossaryDialog : public QDialog
 {
     Q_OBJECT
 
@@ -213,9 +213,9 @@ public:
      *
      * @param parent the parent of the new dialog
      */
-    explicit GlossaryDialog(QWidget *parent = 0);
+    explicit GlossaryDialog(QWidget *parent = nullptr);
 
-    virtual ~GlossaryDialog();
+    ~GlossaryDialog() override;
 
     /**
      * Add a new glossary.
@@ -227,7 +227,7 @@ public:
     void addGlossary(Glossary* newgloss, bool folded = true);
 
 protected:
-    void keyPressEvent(QKeyEvent*);
+    void keyPressEvent(QKeyEvent*) override;
 
 private:
     class Private;
